@@ -3,7 +3,7 @@
 use strict;
 
 use Graphics::Framebuffer;
-use List::Util qw(min max);
+use List::Util qw(min max shuffle);
 use Time::HiRes qw(sleep time);
 # use Data::Dumper::Simple; $Data::Dumper::Sortkeys=1;
 
@@ -52,7 +52,7 @@ my $center_y      = $YY / 2;
 my $factor        = 5;
 
 $F->cls('OFF');
-
+# if (0){
 print_it($F, 'Plotting Test');
 $s = time + $factor;
 while (time < $s) {
@@ -74,8 +74,9 @@ $s = time + $factor;
 $angle = 0;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->angle_line({'x' => $center_x, 'y' => $center_y, 'radius' => ($center_y - $F->{'Y_CLIP'}), 'angle' => $angle++});
-    $angle = 0 if ($angle >= 360);
+    $F->angle_line({'x' => $center_x, 'y' => $center_y, 'radius' => ($center_y - $F->{'Y_CLIP'}), 'angle' => $angle});
+    $angle += 1.1;
+    $angle -= 360 if ($angle >= 360);
 } ## end for (my $l = $F->{'Y_CLIP'...})
 
 print_it($F, 'Box Test');
@@ -576,12 +577,12 @@ $image = $F->load_image(
         'x'      => 0,
           'y'      => 0,
           'width'  => $XX,
-          'height' => $YY,
+          'height' => $YY - $F->{'Y_CLIP'},
           'file'   => 'images/testpattern.jpg'
     }
 );
 $F->blit_write($image);
-sleep $factor/2;
+sleep 1;
 
 print_it($F, 'Testing Image blitting');
 
@@ -589,9 +590,9 @@ $image = $F->load_image(
     {
         'x'      => 0,
           'y'      => 0,
-          'width'  => min(600, $XX / 2),
-          'height' => min(405, $YY / 2),
-          'file'   => 'images/RWBY_Faces.png'
+          'width'  => int($XX/3),
+          'height' => int($YY/3),
+          'file'   => 'images/RWBY_Logo.jpg'
     }
 );
 $s = time + $factor;
@@ -601,9 +602,18 @@ while (time < $s) {
     $F->blit_write($image);
 }
 
-
+print_it($F, "Testing Image rotate");
+$image = $F->load_image(
+    {
+        'x'      => 0,
+          'y'      => 0,
+          'width'  => int($XX/3),
+          'height' => int($YY/3),
+          'file'   => 'images/RWBY_Oh_No.jpg'
+    }
+);
 $angle = 0;
-$s = time + $factor;
+$s = time + ($factor * 2);
 while (time < $s) {
     my $rot = $F->blit_transform(
         {
@@ -615,13 +625,22 @@ while (time < $s) {
     );
     $rot->{'x'} = abs(($XX - $rot->{'width'})/2);
     $rot->{'y'} = abs(($YY - $rot->{'height'})/2);
-    print_it($F, "Testing Image rotate $angle degrees");
     $F->blit_write($rot);
-    $angle+=10;
+    $angle += 5;
     $angle = 0 if ($angle >= 360);
 }
 
+$image = $F->load_image(
+    {
+        'x'      => 0,
+          'y'      => 0,
+          'width'  => int($XX/3),
+          'height' => int($YY/3),
+          'file'   => 'images/RWBY_Faces.png'
+    }
+);
 $s = time + $factor;
+$angle = 0; # Just re-using this variable
 while (time < $s) {
     foreach my $dir (qw(normal horizontal normal vertical)) {
         my $rot = $F->blit_transform(
@@ -634,12 +653,12 @@ while (time < $s) {
         $rot->{'y'} = abs(($YY - $rot->{'height'})/2);
         print_it($F, "Testing Image flip $dir");
         $F->blit_write($rot);
-        sleep .1;
+        sleep .5 unless($angle);
     }
+    $angle++;
 }
 # sleep $factor;
 
-
 print_it($F, 'Testing Monochrome Image blitting');
 
 $image->{'image'} = $F->monochrome({'image' => $image->{'image'}, 'bits' => $F->{'BITS'}});
@@ -650,33 +669,47 @@ while (time < $s) {
     $F->blit_write($image);
 }
 
-print_it($F, 'Testing Animated Image Display');
-my @list = (
-    [502,242,'RWBY_Kick_Butt.gif'],
-    [402,227,'RWBY_Yang_Kick_Butt.gif'],
-    [322,182,'RWBY_Yang_Bam.gif'],
-);
+opendir(my $DIR,'images/');
+chomp(my @list = readdir($DIR));
+closedir($DIR);
+@list = shuffle(@list);
 foreach my $info (@list) {
-    $image = $F->load_image(
-        {
-            'x'      => 0,
-            'y'      => 0,
-            'width'  => min($XX,shift(@{$info})),
-            'height' => min($YY,shift(@{$info})),
-            'file'   => 'images/' . shift(@{$info}),
-            'center' => 3
-    }
-    );
-    $s = time + ($factor * 2);
-    if (defined($image)) {
-        $F->cls();
-        while (time <= $s) {
-            foreach my $frame (0 .. (scalar(@{$image}) - 1)) {
-                my $blit_time = time;
-                $F->blit_write($image->[$frame]);
-                my $delay = (($image->[$frame]->{'tags'}->{'gif_delay'} * (.01 - (time - $blit_time))));
-                if ($delay > 0) {
-                    sleep $delay;
+    next unless ($info =~ /\.gif$/i);
+    for $angle (0 .. 1) {
+        if ($angle) {
+            print_it($F, "Testing Animated Image Display of '$info' fullscreen");
+            $image = $F->load_image(
+                {
+                    'width'  => $XX,
+                      'height' => $YY - $F->{'Y_CLIP'},
+                      'file'   => "images/$info",
+                      'center' => 3
+                }
+            );
+        } else {
+            print_it($F, "Testing Animated Image Display of '$info' at native size");
+            $image = $F->load_image(
+                {
+                    'file'   => "images/$info",
+                      'center' => 3
+                }
+            );
+        }
+        $s = time + ($factor);
+        if (defined($image)) {
+            $F->cls();
+            while (time <= $s) {
+                foreach my $frame (0 .. (scalar(@{$image}) - 1)) {
+                    if (time > ($s * 3)) {
+                        print_it($F, 'Your System is Too Slow To Complete The Animation','FF9999FF');
+                        sleep 2;
+                        last;
+                    }
+                    $F->blit_write($image->[$frame]);
+                    my $delay = (($image->[$frame]->{'tags'}->{'gif_delay'} * .01));
+                    if ($delay > 0) {
+                        sleep $delay;
+                    }
                 }
             }
         }
@@ -690,6 +723,7 @@ exit(0);
 sub print_it {
     my $fb      = shift;
     my $message = shift;
+    my $color   = shift || '00FF00FF';
 
     $fb->normal_mode();
     $fb->clip_reset();
@@ -702,7 +736,7 @@ sub print_it {
                 'x'            => 5 * $xm,
                   'y'            => max(9, 20 * $ym),
                   'height'       => max(10, 20 * $ym),
-                  'color'        => '00FF00',
+                  'color'        => $color,
                   'text'         => $message,
                   'bounding_box' => 1,
                   'center'       => $fb->{'CENTER_X'},
