@@ -16,13 +16,14 @@ use Time::HiRes qw(sleep);
 
 my $args = join('',@ARGV);
 
-my $file = 0;
-$file = 1 if ($args =~ /file/i);
-
-my $errors = 0;
-$errors = 1 if ($args =~ /errors/i);
-my $auto = 0;
-$auto = 1 if ($args =~ /auto/i);
+my $file       = 0;
+$file          = 1 if ($args =~ /file/i);
+my $errors     = 0;
+$errors        = 1 if ($args =~ /errors/i);
+my $auto       = 0;
+$auto          = 1 if ($args =~ /auto/i);
+my $fullscreen = 0;
+$fullscreen    = 1 if ($args =~ /full/i);
 
 my @fbs;
 foreach my $p (qw(/dev/graphics/fb /dev/fb)) {
@@ -111,11 +112,10 @@ sub show {
         my $name = $pics[int(rand($p))];
         print_it($FB,"Loading image $name");
         my $image;
-        if ($name =~ /\.gif$/i && $FB->{'XRES'} > 800) {
+        unless ($fullscreen) {
             $image = $FB->load_image(
                 {
-                    'width'      => $FB->{'XRES'}/2,
-                    'height'     => $FB->{'YRES'}/2,
+                    'noscale'    => 1,
                     'file'       => $name,
                     'center'     => $FB->{'CENTER_XY'},
                     'autolevels' => $auto
@@ -132,6 +132,7 @@ sub show {
                 }
             );
         }
+#        warn Dumper($image);exit;
         last unless($RUNNING);
         if (defined($image)) {
             $FB->cls();
@@ -141,7 +142,7 @@ sub show {
                     last unless($RUNNING);
                     foreach my $frame (0 .. (scalar(@{$image}) - 1)) {
                         last unless($RUNNING);
-                        if (0 && $frame) {
+                        if (0&&$frame) {
                             $FB->blit_write(
                                 $FB->blit_transform(
                                     {
@@ -155,7 +156,8 @@ sub show {
                         } else {
                             $FB->blit_write($image->[$frame]);
                         }
-                        sleep ($image->[$frame]->{'tags'}->{'gif_delay'} / 100);
+                        my $delay = ($image->[$frame]->{'tags'}->{'gif_delay'} / 100);
+                        sleep $delay if ($delay > 0);
                     }
                 }
             } else {
